@@ -19,7 +19,7 @@ from model_bakery.exceptions import (
     ModelNotFound,
 )
 from model_bakery.timezone import tz_aware
-from tests.generic import models
+from tests.generic import baker_recipes, models
 from tests.generic.forms import DummyGenericIPAddressFieldForm
 
 
@@ -286,6 +286,12 @@ class TestBakerPrepareSavingRelatedInstances:
         assert lonely_person.pk is None
         assert lonely_person.only_friend.pk
 
+    def test_recipe_prepare_model_with_one_to_one_and_save_related(self):
+        lonely_person = baker_recipes.lonely_person.prepare(_save_related=True)
+
+        assert lonely_person.pk is None
+        assert lonely_person.only_friend.pk
+
 
 @pytest.mark.django_db
 class TestBakerCreatesAssociatedModels(TestCase):
@@ -629,6 +635,38 @@ class TestHandlingContentTypeField:
         assert isinstance(dummy, models.DummyGenericForeignKeyModel)
         assert isinstance(dummy.content_type, ContentType)
 
+    def test_create_model_with_contenttype_with_content_object(self):
+        """Test creating model with contenttype field and populating that field by function."""
+        from django.contrib.contenttypes.models import ContentType
+
+        def get_dummy_key():
+            return baker.make("Person")
+
+        dummy = baker.make(
+            models.DummyGenericForeignKeyModel, content_object=get_dummy_key
+        )
+        assert isinstance(dummy, models.DummyGenericForeignKeyModel)
+        assert isinstance(dummy.content_type, ContentType)
+        assert isinstance(dummy.content_object, models.Person)
+
+    def test_create_model_with_contenttype_field_and_proxy_model(self):
+        from django.contrib.contenttypes.models import ContentType
+
+        class ProxyPerson(models.Person):
+            class Meta:
+                proxy = True
+                app_label = "generic"
+
+        dummy = baker.make(
+            models.DummyGenericForeignKeyModel,
+            content_object=baker.make(ProxyPerson, name="John Doe"),
+        )
+        dummy.refresh_from_db()
+        assert isinstance(dummy, models.DummyGenericForeignKeyModel)
+        assert isinstance(dummy.content_type, ContentType)
+        assert isinstance(dummy.content_object, ProxyPerson)
+        assert dummy.content_object.name == "John Doe"
+
 
 @pytest.mark.skipif(
     not BAKER_CONTENTTYPES, reason="Django contenttypes framework is not installed"
@@ -1124,3 +1162,16 @@ class TestAutoNowFields:
         assert instance.created == now
         assert instance.updated == now
         assert instance.sent_date == now
+
+    @pytest.mark.django_db
+    def test_make_with_auto_now_and_fill_optional(self):
+        instance = baker.make(
+            models.ModelWithAutoNowFields,
+            _fill_optional=True,
+        )
+        created, updated = instance.created, instance.updated
+
+        instance.refresh_from_db()
+
+        assert instance.created == created
+        assert instance.updated == updated
